==> material-ui-shell-2.0.7.tgz: package/es/components/MenuHeader/MenuHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { useAuth } from 'base-shell/lib/providers/Auth';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';
import { Avatar, IconButton, List, ListItem, ListItemAvatar, ListItemSecondaryAction, ListItemText, Paper } from '@mui/material';
import { ChevronLeft, ChevronRight, ChromeReaderMode, Person as PersonIcon, ArrowDropDown as ArrowDropDownIcon, ArrowDropUp as ArrowDropUpIcon, Brightness4 as Brightness4Icon, BrightnessHigh as BrightnessHighIcon } from '@mui/icons-material';
import { useTheme } from '@mui/material';

var MenuHeader = function MenuHeader() {
  var _useAuth = useAuth(),
      auth = _useAuth.auth;

  var _useAppTheme = useAppTheme(),
      toggleThisTheme = _useAppTheme.toggleThisTheme,
      isDarkMode = _useAppTheme.isDarkMode,
      isRTL = _useAppTheme.isRTL;

  var menuContext = useMenu();
  var theme = useTheme();
  var authData = auth;

  var _ref = menuContext || {},
      toggleThis = _ref.toggleThis,
      isDesktop = _ref.isDesktop,
      isMiniMode = _ref.isMiniMode,
      isMenuOpen = _ref.isMenuOpen,
      isMiniSwitchVisibility = _ref.isMiniSwitchVisibility,
      isAuthMenuOpen = _ref.isAuthMenuOpen;

  var isAuthenticated = auth.isAuthenticated;

  var AvatarConstructor = function AvatarConstructor(_ref2) {
    var src = _ref2.src,
        alt = _ref2.alt,
        avatar = _ref2.avatar;
    return /*#__PURE__*/React.createElement(ListItemAvatar, {
      onClick: function onClick() {
        return toggleThis('isAuthMenuOpen');
      }
    }, /*#__PURE__*/React.createElement(Avatar, {
      src: src,
      alt: alt
    }, avatar));
  };

  var styles = {
    icon: {
      color: theme.palette.grey.A100,
      cursor: 'pointer'
    },
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: theme.spacing(1)
    }, theme.mixins.toolbar)
  };
  return /*#__PURE__*/React.createElement(Paper, {
    square: true,
    elevation: 3,
    sx: {
      backgroundColor: function backgroundColor(t) {
        return t.palette.mode === 'dark' ? t.palette.background.default : t.palette.primary.dark;
      },
      margin: 0,
      padding: 0
    }
  }, isMiniMode && isAuthenticated && /*#__PURE__*/React.createElement("div", {
    style: _extends({}, styles.toolbar)
  }), /*#__PURE__*/React.createElement(List, {
    sx: _extends({}, !isAuthenticated ? styles.toolbar : {})
  }, !isMiniMode && /*#__PURE__*/React.createElement(ListItem, {
    sx: _extends({
      color: function color(t) {
        return theme.palette.grey.A100;
      },
      cursor: 'pointer'
    }, theme.mixins.toolbar)
  }, isAuthenticated && (authData.photoURL ? AvatarConstructor({
    src: authData.photoURL,
    alt: 'user'
  }) : AvatarConstructor({
    avatar: authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)
  })), /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      toggleThisTheme('isDarkMode');
    }
  }, isDarkMode ? /*#__PURE__*/React.createElement(BrightnessHighIcon, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(Brightness4Icon, {
    sx: _extends({}, styles.icon)
  })), isDesktop && /*#__PURE__*/React.createElement(React.Fragment, null, isMiniSwitchVisibility && /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      toggleThis('isMiniMode', true);
      toggleThis('isMenuOpen', false);
    }
  }, /*#__PURE__*/React.createElement(ChromeReaderMode, {
    sx: _extends({}, styles.icon)
  })), /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    onClick: function onClick() {
      toggleThis('isMenuOpen', false);
    }
  }, isRTL ? /*#__PURE__*/React.createElement(ChevronRight, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(ChevronLeft, {
    sx: _extends({}, styles.icon)
  })), ' '))), isAuthenticated && /*#__PURE__*/React.createElement(ListItem, {
    onClick: function onClick() {
      toggleThis('isAuthMenuOpen');
    }
  }, !isMenuOpen && isMiniMode && isDesktop && (authData.photoURL ? AvatarConstructor({
    src: authData.photoURL,
    alt: 'user'
  }) : AvatarConstructor({
    avatar: authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)
  })), !isMiniMode && /*#__PURE__*/React.createElement(ListItemText, {
    sx: {
      color: function color(t) {
        return theme.palette.grey.A100;
      },
      cursor: 'pointer',
      marginLeft: !isMenuOpen && isDesktop && authData.photoURL ? 7 : undefined
    },
    secondaryTypographyProps: {
      color: function color(t) {
        return theme.palette.grey.A100;
      }
    },
    primary: authData.displayName,
    secondary: authData.email
  }), isMenuOpen && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
    onClick: function onClick() {
      toggleThis('isAuthMenuOpen');
    }
  }, /*#__PURE__*/React.createElement(IconButton, null, isAuthMenuOpen ? /*#__PURE__*/React.createElement(ArrowDropUpIcon, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(ArrowDropDownIcon, {
    sx: _extends({}, styles.icon)
  }))))));
};

export default MenuHeader;

==> material-ui-shell-2.0.9.tgz: package/es/components/MenuHeader/MenuHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { useAuth } from 'base-shell/lib/providers/Auth';
import { useMenu } from 'material-ui-shell/lib/providers/Menu';
import { useTheme as useAppTheme } from 'material-ui-shell/lib/providers/Theme';
import { Avatar, IconButton, List, ListItem, ListItemAvatar, ListItemSecondaryAction, ListItemText, Paper } from '@mui/material';
import { ChevronLeft, ChevronRight, ChromeReaderMode, Person as PersonIcon, ArrowDropDown as ArrowDropDownIcon, ArrowDropUp as ArrowDropUpIcon, Brightness4 as Brightness4Icon, BrightnessHigh as BrightnessHighIcon } from '@mui/icons-material';
import { useTheme } from '@mui/material/styles';

var MenuHeader = function MenuHeader() {
  var _useAuth = useAuth(),
      auth = _useAuth.auth;

  var _useAppTheme = useAppTheme(),
      toggleThisTheme = _useAppTheme.toggleThisTheme,
      isDarkMode = _useAppTheme.isDarkMode,
      isRTL = _useAppTheme.isRTL;

  var menuContext = useMenu();
  var theme = useTheme();
  var authData = auth;

  var _ref = menuContext || {},
      toggleThis = _ref.toggleThis,
      isDesktop = _ref.isDesktop,
      isMiniMode = _ref.isMiniMode,
      isMenuOpen = _ref.isMenuOpen,
      isMiniSwitchVisibility = _ref.isMiniSwitchVisibility,
      isAuthMenuOpen = _ref.isAuthMenuOpen;

  var isAuthenticated = auth.isAuthenticated;

  var AvatarConstructor = function AvatarConstructor(_ref2) {
    var src = _ref2.src,
        alt = _ref2.alt,
        avatar = _ref2.avatar;
    return /*#__PURE__*/React.createElement(ListItemAvatar, {
      onClick: function onClick() {
        return toggleThis('isAuthMenuOpen');
      }
    }, /*#__PURE__*/React.createElement(Avatar, {
      src: src,
      alt: alt
    }, avatar));
  };

  var styles = {
    icon: {
      color: theme.palette.grey.A100,
      cursor: 'pointer'
    },
    toolbar: _extends({
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'flex-end',
      padding: theme.spacing(1)
    }, theme.mixins.toolbar)
  };
  return /*#__PURE__*/React.createElement(Paper, {
    square: true,
    elevation: 3,
    sx: {
      backgroundColor: function backgroundColor(t) {
        return t.palette.mode === 'dark' ? t.palette.background.default : t.palette.primary.dark;
      },
      margin: 0,
      padding: 0
    }
  }, isMiniMode && isAuthenticated && /*#__PURE__*/React.createElement("div", {
    style: _extends({}, styles.toolbar)
  }), /*#__PURE__*/React.createElement(List, {
    sx: _extends({}, !isAuthenticated ? styles.toolbar : {})
  }, !isMiniMode && /*#__PURE__*/React.createElement(ListItem, {
    sx: _extends({
      color: function color(t) {
        return theme.palette.grey.A100;
      },
      cursor: 'pointer'
    }, theme.mixins.toolbar)
  }, isAuthenticated && (authData.photoURL ? AvatarConstructor({
    src: authData.photoURL,
    alt: 'user'
  }) : AvatarConstructor({
    avatar: authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)
  })), /*#__PURE__*/React.createElement(ListItemSecondaryAction, null, /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      toggleThisTheme('isDarkMode');
    }
  }, isDarkMode ? /*#__PURE__*/React.createElement(BrightnessHighIcon, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(Brightness4Icon, {
    sx: _extends({}, styles.icon)
  })), isDesktop && /*#__PURE__*/React.createElement(React.Fragment, null, isMiniSwitchVisibility && /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      toggleThis('isMiniMode', true);
      toggleThis('isMenuOpen', false);
    }
  }, /*#__PURE__*/React.createElement(ChromeReaderMode, {
    sx: _extends({}, styles.icon)
  })), /*#__PURE__*/React.createElement(IconButton, {
    color: "inherit",
    onClick: function onClick() {
      toggleThis('isMenuOpen', false);
    }
  }, isRTL ? /*#__PURE__*/React.createElement(ChevronRight, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(ChevronLeft, {
    sx: _extends({}, styles.icon)
  })), ' '))), isAuthenticated && /*#__PURE__*/React.createElement(ListItem, {
    onClick: function onClick() {
      toggleThis('isAuthMenuOpen');
    }
  }, !isMenuOpen && isMiniMode && isDesktop && (authData.photoURL ? AvatarConstructor({
    src: authData.photoURL,
    alt: 'user'
  }) : AvatarConstructor({
    avatar: authData.displayName ? authData.displayName[0].toUpperCase() : /*#__PURE__*/React.createElement(PersonIcon, null)
  })), !isMiniMode && /*#__PURE__*/React.createElement(ListItemText, {
    sx: {
      color: function color(t) {
        return theme.palette.grey.A100;
      },
      cursor: 'pointer',
      marginLeft: !isMenuOpen && isDesktop && authData.photoURL ? 7 : undefined
    },
    secondaryTypographyProps: {
      color: function color(t) {
        return theme.palette.grey.A100;
      }
    },
    primary: authData.displayName,
    secondary: authData.email
  }), isMenuOpen && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
    onClick: function onClick() {
      toggleThis('isAuthMenuOpen');
    }
  }, /*#__PURE__*/React.createElement(IconButton, null, isAuthMenuOpen ? /*#__PURE__*/React.createElement(ArrowDropUpIcon, {
    sx: _extends({}, styles.icon)
  }) : /*#__PURE__*/React.createElement(ArrowDropDownIcon, {
    sx: _extends({}, styles.icon)
  }))))));
};

export default MenuHeader;
